package lcsb.mapviewer.services.interfaces;

import java.io.IOException;
import java.util.Collection;
import java.util.Set;

import lcsb.mapviewer.common.IProgressUpdater;
import lcsb.mapviewer.model.map.graph.DataMining;
import lcsb.mapviewer.model.map.graph.DataMiningSet;
import lcsb.mapviewer.model.map.graph.DataMiningType;
import lcsb.mapviewer.model.map.reaction.Reaction;
import lcsb.mapviewer.model.map.species.Element;
import lcsb.mapviewer.services.utils.InvalidDataMiningInputFile;
import lcsb.mapviewer.services.view.DataMiningSetView;

/**
 * This service manages data mining data.
 * 
 * @author Piotr Gawron
 * 
 */
public interface IDataMiningService {

	/**
	 * This method creates set of {@link DataMining} elements from input file.
	 * 
	 * @param filename
	 *          file where data mining data is stored
	 * @param nodes
	 *          nodes for which data mining connections shoul be generated
	 * @param reactions
	 *          list of already existing reactions in the model
	 * @param type
	 *          {@link DataMiningType} defining type of the input entries
	 * @param updater
	 *          callback function that update information about progress of the
	 *          function execution
	 * @return data mining connections for given data
	 * @throws IOException
	 *           thrown when there is a problem with input file
	 * @throws InvalidDataMiningInputFile
	 *           thrown when the input file is invalid
	 */
	Set<DataMining> parseData(String filename, DataMiningType type, Collection<Element> nodes, Set<Reaction> reactions, IProgressUpdater updater)
			throws IOException, InvalidDataMiningInputFile;

	/**
	 * This method creates set of {@link DataMining} elements from input file.
	 * 
	 * @param dataMiningSet
	 *          data mining set where information about parsed file is stored
	 * @param nodes
	 *          nodes for which data mining connections shoul be generated
	 * @param reactions
	 *          list of already existing reactions in the model
	 * @param updater
	 *          callback function that update information about progress of the
	 *          function execution
	 * @return data mining connections for given data
	 * @throws InvalidDataMiningInputFile
	 *           thrown when the input file is invalid
	 */
	Set<DataMining> parseData(DataMiningSet dataMiningSet, Collection<Element> nodes, Set<Reaction> reactions, IProgressUpdater updater)
			throws InvalidDataMiningInputFile;

	/**
	 * Returns byte array containing data from original input file that was used
	 * in this {@link DataMiningSet}.
	 * 
	 * @param dms
	 *          {@link DataMiningSetView} for which we want to retrieve original
	 *          file data
	 * @return original data file for given {@link DataMiningSet}
	 */
	byte[] getInputDataForLayout(DataMiningSetView dms);
}
