package lcsb.mapviewer.services.search.data;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import lcsb.mapviewer.services.search.IHeavyView;
import lcsb.mapviewer.services.search.ISearchResultView;

/**
 * Class representing result of search query.
 * 
 * @author Piotr Gawron
 *
 */
public class SearchElementResult implements Serializable, ISearchResultView {
	/**
	 * 
	 */
	private static final long	serialVersionUID = 1L;

	/**
	 * String that identifies this search result (all results with the same id
	 * should have the same content).
	 */
	private String						uniqueId;

	/**
	 * List of elements found as a results of the search operation.
	 */
	private List<IHeavyView>	elements				 = new ArrayList<>();

	/**
	 * Default constructor.
	 * 
	 * @param name
	 *          search query used to create a result
	 */
	public SearchElementResult(String name) {
		setName(name);
	}

	@Override
	public String getUniqueId() {
		return uniqueId;
	}

	@Override
	public void setUniqueId(String uniqueId) {
		this.uniqueId = uniqueId;
	}

	/**
	 * Returns string used to create this result.
	 * 
	 * @return string used to create this result
	 */
	public String getName() {
		return uniqueId;
	}

	/**
	 * Sets string used to create this result.
	 * 
	 * @param name
	 *          string used to create this result
	 */
	public void setName(String name) {
		this.uniqueId = name;
	}

	/**
	 * @return the elements
	 * @see #elements
	 */
	public List<IHeavyView> getElements() {
		return elements;
	}

	/**
	 * @param elements
	 *          the elements to set
	 * @see #elements
	 */
	public void setElements(List<IHeavyView> elements) {
		this.elements = elements;
	}

	/**
	 * Adds elements to this search result.
	 * 
	 * @param results
	 *          elements to add
	 */
	public void addAll(List<IHeavyView> results) {
		elements.addAll(results);
	}

	/**
	 * Adds element to this search result.
	 * 
	 * @param result
	 *          element to add
	 */
	public void add(FullAliasView result) {
		elements.add(result);
	}

	/**
	 * Returns number of elements in this search result.
	 * 
	 * @return number of elements in this search result
	 */
	public int size() {
		return elements.size();
	}

	/**
	 * Gets i-th element in this search result.
	 * 
	 * @param i
	 *          index of the element to return
	 * @return i-th element in this search result
	 */
	public IHeavyView get(int i) {
		return elements.get(i);
	}

}
