package lcsb.mapviewer.services.search.layout;

import java.util.ArrayList;
import java.util.List;

import org.apache.log4j.Logger;

import lcsb.mapviewer.model.map.layout.ColorSchema;
import lcsb.mapviewer.model.map.layout.GeneVariation;
import lcsb.mapviewer.model.map.species.Element;
import lcsb.mapviewer.services.search.IHeavyView;
import lcsb.mapviewer.services.search.data.LightAliasView;
import lcsb.mapviewer.services.utils.data.ColorSchemaType;

/**
 * Heavy {@link LightAliasView view} for alias representing data that should be
 * sent to client.
 * 
 * @author Piotr Gawron
 *
 */
public class FullLayoutAliasView extends LightLayoutAliasView implements IHeavyView {

	/**
	 * Default class logger.
	 */
	@SuppressWarnings("unused")
	private static Logger				logger					 = Logger.getLogger(FullLayoutAliasView.class);

	/**
	 * 
	 */
	private static final long		serialVersionUID = 1L;

	/**
	 * Description.
	 * 
	 * @see ColorSchema#description
	 */
	private String							description;

	/**
	 * Type of the layout.
	 * 
	 * @see ColorSchema#getClass()
	 */
	private ColorSchemaType			type;

	/**
	 * List of gene variants.
	 */
	private List<GeneVariation>	geneVariations	 = new ArrayList<>();

	/**
	 * Default constructor.
	 * 
	 * @param alias
	 *          object for which vie is created
	 */
	protected FullLayoutAliasView(Element alias) {
		super(alias);
	}

	/**
	 * @return the description
	 * @see #description
	 */
	public String getDescription() {
		return description;
	}

	/**
	 * @param description
	 *          the description to set
	 * @see #description
	 */
	public void setDescription(String description) {
		this.description = description;
	}

	/**
	 * @return the type
	 * @see #type
	 */
	public ColorSchemaType getType() {
		return type;
	}

	/**
	 * @param type
	 *          the type to set
	 * @see #type
	 */
	public void setType(ColorSchemaType type) {
		this.type = type;
	}

	/**
	 * @return the geneVariations
	 * @see #geneVariations
	 */
	public List<GeneVariation> getGeneVariations() {
		return geneVariations;
	}

	/**
	 * @param geneVariations
	 *          the geneVariations to set
	 * @see #geneVariations
	 */
	public void setGeneVariations(List<GeneVariation> geneVariations) {
		this.geneVariations = geneVariations;
	}

}
