package lcsb.mapviewer.services.search.layout;

import org.apache.log4j.Logger;

import com.google.gson.Gson;

import lcsb.mapviewer.common.Pair;
import lcsb.mapviewer.common.geometry.ColorParser;
import lcsb.mapviewer.model.map.layout.ColorSchema;
import lcsb.mapviewer.model.map.species.Element;
import lcsb.mapviewer.services.search.ElementViewFactory;

/**
 * Factory class for {@link LightLayoutAliasView} class.
 * 
 * @author Piotr Gawron
 * 
 */
public class LightLayoutAliasViewFactory extends ElementViewFactory<Pair<Element, ColorSchema>, LightLayoutAliasView> {

	/**
	 * Parser to map color into object that can be returned to client side.
	 */

	private ColorParser		parser = new ColorParser();

	/**
	 * Default class logger.
	 */
	@SuppressWarnings("unused")
	private static Logger	logger = Logger.getLogger(LightLayoutAliasViewFactory.class);

	@Override
	public LightLayoutAliasView create(Pair<Element, ColorSchema> pair) {
		LightLayoutAliasView result = new LightLayoutAliasView(pair.getLeft());
		if (pair.getRight().getColor() != null) {
			result.setColor(parser.colorToMap(pair.getRight().getColor()));
		}
		result.setValue(pair.getRight().getValue());
		return result;
	}

	@Override
	public String createGson(LightLayoutAliasView object) {
		return new Gson().toJson(object);
	}
}
