package lcsb.mapviewer.services.search.layout;

import java.awt.Color;

import lcsb.mapviewer.model.map.reaction.Reaction;
import lcsb.mapviewer.services.search.ElementView;

/**
 * Light {@link ElementView view} for {@link Reaction} representing data that
 * should be send to client about reaction related to
 * {@link lcsb.mapviewer.model.map.layout.Layout}.
 * 
 * @author Piotr Gawron
 *
 */
public class LightLayoutReactionView extends ElementView {

	/**
	 * 
	 */
	private static final long	serialVersionUID = 1L;

	/**
	 * Width of highlighted {@link Reaction} in a a layout.
	 */
	private Double						width;

	/**
	 * Color used to highlight {@link Reaction} in a layout.
	 */
	private Color							color;

	/**
	 * Should the reaction be reversed when visualizing..
	 */
	private Boolean						reverse;

	/**
	 * Normalized value repesenting expresion (used instead of color).
	 */
	private Double						value;

	/**
	 * Default constructor.
	 * 
	 * @param reaction
	 *          original object from which this on is created
	 */
	public LightLayoutReactionView(Reaction reaction) {
		super(reaction.getId(), reaction.getModel().getId());
	}

	/**
	 * Constructor that should be used only for (de)serialization.
	 */
	protected LightLayoutReactionView() {
		super();
	}

	/**
	 * @return the color
	 * @see #color
	 */
	public Color getColor() {
		return color;
	}

	/**
	 * @param color
	 *          the color to set
	 * @see #color
	 */
	public void setColor(Color color) {
		this.color = color;
	}

	@Override
	public String toString() {
		return "[" + this.getClass().getSimpleName() + "] " + //
				"reaction_id: " + getIdObject() + ", " + //
				"width: " + getWidth() + ", " + //
				"color: " + getColor() + ", ";

	}

	/**
	 * @return the width
	 * @see #width
	 */
	public Double getWidth() {
		return width;
	}

	/**
	 * @param width
	 *          the width to set
	 * @see #width
	 */
	public void setWidth(Double width) {
		this.width = width;
	}

	/**
	 * @return the reverse
	 * @see #reverse
	 */
	public Boolean getReverse() {
		return reverse;
	}

	/**
	 * @param reverse
	 *          the reverse to set
	 * @see #reverse
	 */
	public void setReverse(Boolean reverse) {
		this.reverse = reverse;
	}

	/**
	 * @return the value
	 * @see #value
	 */
	public Double getValue() {
		return value;
	}

	/**
	 * @param value
	 *          the value to set
	 * @see #value
	 */
	public void setValue(Double value) {
		this.value = value;
	}

}
