package lcsb.mapviewer.services.view;

import java.io.Serializable;

import lcsb.mapviewer.model.map.MiriamData;

/**
 * View representation of the Annotation (MiriamData). Contains direct url,
 * sometimes also a summary of the link.
 * 
 * @author Piotr Gawron
 * 
 */
public class AnnotationView extends AbstractView<MiriamData> implements Serializable {

	/**
	 * 
	 */
	private static final long	serialVersionUID = 1L;

	/**
	 * Common name of the link that should be presented to user.
	 */
	private String						name;

	/**
	 * Type of the annotation.
	 */
	private String						type;

	/**
	 * Link to the miriam resource.
	 */
	private String						link;

	/**
	 * Short summary of the data represented in the link (at most few sentences).
	 */
	private String						summary;

	private String						resource;

	/**
	 * Default constructor.
	 * 
	 * @param object
	 *          miriamData which this view shoul visualize
	 */
	protected AnnotationView(MiriamData object) {
		super(object);
	}

	/**
	 * Default constructor. Should be used only for deserialization.
	 */
	protected AnnotationView() {
	}

	/**
	 * @return the name
	 * @see #name
	 */
	public String getName() {
		return name;
	}

	/**
	 * @param name
	 *          the name to set
	 * @see #name
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * @return the link
	 * @see #link
	 */
	public String getLink() {
		return link;
	}

	/**
	 * @param link
	 *          the link to set
	 * @see #link
	 */
	public void setLink(String link) {
		this.link = link;
	}

	/**
	 * @return the summary
	 * @see #summary
	 */
	public String getSummary() {
		return summary;
	}

	/**
	 * @param summary
	 *          the summary to set
	 * @see #summary
	 */
	public void setSummary(String summary) {
		this.summary = summary;
	}

	@Override
	public String toString() {
		return name + " - " + type + " (" + link + ")";
	}

	/**
	 * @return the type
	 * @see #type
	 */
	public String getType() {
		return type;
	}

	/**
	 * @param type
	 *          the type to set
	 * @see #type
	 */
	public void setType(String type) {
		this.type = type;
	}

	/**
	 * @return the resource
	 * @see #resource
	 */
	public String getResource() {
		return resource;
	}

	/**
	 * @param resource the resource to set
	 * @see #resource
	 */
	public void setResource(String resource) {
		this.resource = resource;
	}

}
