package lcsb.mapviewer.services.view;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import lcsb.mapviewer.model.map.OverviewImage;

/**
 * View representatin of a {@link OverviewImage}. It's a light structre that
 * present {@link OverviewImage} data to the client side.
 * 
 * @author Piotr Gawron
 * 
 */
public class OverviewImageView extends AbstractView<OverviewImage> implements Serializable {

	/**
	 * 
	 */
	private static final long				serialVersionUID	= 1L;

	/**
	 * Name of the file (relative to the main image data framework directory).
	 */
	private String									filename;
	/**
	 * Width of the image.
	 */
	private Integer									width;
	/**
	 * Height of the image.
	 */
	private Integer									height;

	/**
	 * List of links that are accesible from this image.
	 */
	private List<OverviewLinkView>	links							= new ArrayList<OverviewLinkView>();

	/**
	 * Default constructor.
	 * 
	 * @param object
	 *          original {@link OverviewImage}
	 */
	protected OverviewImageView(OverviewImage object) {
		super(object);
	}

	/**
	 * Default constructor. Should be used only for deserialization.
	 */
	protected OverviewImageView() {
	}

	/**
	 * @return the filename
	 * @see #filename
	 */
	public String getFilename() {
		return filename;
	}

	/**
	 * @param filename
	 *          the filename to set
	 * @see #filename
	 */
	public void setFilename(String filename) {
		this.filename = filename;
	}

	/**
	 * @return the width
	 * @see #width
	 */
	public Integer getWidth() {
		return width;
	}

	/**
	 * @param width
	 *          the width to set
	 * @see #width
	 */
	public void setWidth(Integer width) {
		this.width = width;
	}

	/**
	 * @return the height
	 * @see #height
	 */
	public Integer getHeight() {
		return height;
	}

	/**
	 * @param height
	 *          the height to set
	 * @see #height
	 */
	public void setHeight(Integer height) {
		this.height = height;
	}

	/**
	 * @return the links
	 * @see #links
	 */
	public List<OverviewLinkView> getLinks() {
		return links;
	}

	/**
	 * @param links
	 *          the links to set
	 * @see #links
	 */
	public void setLinks(List<OverviewLinkView> links) {
		this.links = links;
	}
}
