package lcsb.mapviewer.services.view;

import java.awt.geom.Point2D;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import org.primefaces.model.map.LatLng;

import lcsb.mapviewer.model.map.OverviewLink;

/**
 * View representatin of a {@link OverviewLink}. It's a light structre that
 * present {@link OverviewLink} data to the client side.
 * 
 * @author Piotr Gawron
 * 
 */
public class OverviewLinkView extends AbstractView<OverviewLink> implements Serializable {

	/**
	 * 
	 */
	private static final long	serialVersionUID	= 1L;

	/**
	 * List of coordinates that correspond to polygon area that should be
	 * clickable on parent image.
	 */
	private List<Point2D>			polygon						= new ArrayList<Point2D>();

	/**
	 * Zoom level when link is representing
	 * {@link lcsb.mapviewer.model.map.OverviewModelLink OverviewModelLink}.
	 */
	private Integer						zoomLevel;

	/**
	 * Lat Lng coordinate when link is representing
	 * {@link lcsb.mapviewer.model.map.OverviewModelLink OverviewModelLink}.
	 */
	private LatLng						latLng;

	/**
	 * Model identinfier when link is representing
	 * {@link lcsb.mapviewer.model.map.OverviewModelLink OverviewModelLink}.
	 */
	private Integer						modelLinkId;

	/**
	 * Image identinfier when link is representing
	 * {@link lcsb.mapviewer.model.map.OverviewImageLink OverviewImageLink}.
	 */
	private Integer						imageLinkId;

	/**
	 * Query string when link is representing
	 * {@link lcsb.mapviewer.model.map.OverviewSearchLink OverviewSearchLink}.
	 */
	private String						query;

	/**
	 * Type of the class that implements
	 * {@link lcsb.mapviewer.model.map.OverviewLink OverviewLink}.
	 */
	private String						type;

	/**
	 * Default constructor.
	 * 
	 * @param object
	 *          for which the view is created
	 */
	protected OverviewLinkView(OverviewLink object) {
		super(object);
	}

	/**
	 * Default constructor. Should be used only for deserialization.
	 */
	protected OverviewLinkView() {
	}

	/**
	 * @return the polygon
	 * @see #polygon
	 */
	public List<Point2D> getPolygon() {
		return polygon;
	}

	/**
	 * @param polygon
	 *          the polygon to set
	 * @see #polygon
	 */
	public void setPolygon(String polygon) {
		String[] tmp = polygon.split(" ");
		for (String string : tmp) {
			Double x = Double.valueOf(string.split(",")[0].trim());
			Double y = Double.valueOf(string.split(",")[1].trim());
			this.polygon.add(new Point2D.Double(x, y));
		}
	}

	/**
	 * @return the zoomLevel
	 * @see #zoomLevel
	 */
	public Integer getZoomLevel() {
		return zoomLevel;
	}

	/**
	 * @param zoomLevel
	 *          the zoomLevel to set
	 * @see #zoomLevel
	 */
	public void setZoomLevel(Integer zoomLevel) {
		this.zoomLevel = zoomLevel;
	}

	/**
	 * @return the modelLinkId
	 * @see #modelLinkId
	 */
	public Integer getModelLinkId() {
		return modelLinkId;
	}

	/**
	 * @param modelLinkId
	 *          the modelLinkId to set
	 * @see #modelLinkId
	 */
	public void setModelLinkId(Integer modelLinkId) {
		this.modelLinkId = modelLinkId;
	}

	/**
	 * @return the imageLinkId
	 * @see #imageLinkId
	 */
	public Integer getImageLinkId() {
		return imageLinkId;
	}

	/**
	 * @param imageLinkId
	 *          the imageLinkId to set
	 * @see #imageLinkId
	 */
	public void setImageLinkId(Integer imageLinkId) {
		this.imageLinkId = imageLinkId;
	}

	/**
	 * @return the query
	 * @see #query
	 */
	public String getQuery() {
		return query;
	}

	/**
	 * @param query
	 *          the query to set
	 * @see #query
	 */
	public void setQuery(String query) {
		this.query = query;
	}

	/**
	 * @return the type
	 * @see #type
	 */
	public String getType() {
		return type;
	}

	/**
	 * @param type
	 *          the type to set
	 * @see #type
	 */
	public void setType(String type) {
		this.type = type;
	}

	/**
	 * @return the latLng
	 * @see #latLng
	 */
	public LatLng getLatLng() {
		return latLng;
	}

	/**
	 * @param latLng
	 *          the latLng to set
	 * @see #latLng
	 */
	public void setLatLng(LatLng latLng) {
		this.latLng = latLng;
	}

}
