package lcsb.mapviewer.services.view;

import java.util.Set;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;

import com.google.gson.Gson;

import lcsb.mapviewer.annotation.data.Article;
import lcsb.mapviewer.annotation.services.PubmedParser;
import lcsb.mapviewer.annotation.services.PubmedSearchException;
import lcsb.mapviewer.common.exception.InvalidArgumentException;
import lcsb.mapviewer.common.exception.NotImplementedException;
import lcsb.mapviewer.model.map.BioEntity;
import lcsb.mapviewer.model.map.MiriamData;
import lcsb.mapviewer.model.map.MiriamType;
import lcsb.mapviewer.model.map.model.Model;

/**
 * Factory class for {@link LayoutView} class.
 * 
 * @author Piotr Gawron
 * 
 */
public class PubmedAnnotatedElementsViewFactory extends AbstractViewFactory<MiriamData, PubmedAnnotatedElementsView> {

	/**
	 * Default class logger.
	 */
	private static Logger	logger = Logger.getLogger(PubmedAnnotatedElementsViewFactory.class);

	/**
	 * Local backend to the pubmed data.
	 */
	@Autowired
	private PubmedParser	pubmedParser;

	@Override
	public PubmedAnnotatedElementsView create(MiriamData element) {
		PubmedAnnotatedElementsView result = new PubmedAnnotatedElementsView(element);
		if (element == null) {
			return result;
		} else if (!MiriamType.PUBMED.equals(element.getDataType())) {
			throw new InvalidArgumentException("Only " + MiriamType.PUBMED + " types are valid");
		}
		try {
			result.setArticle(pubmedParser.getPubmedArticleById(Integer.valueOf(element.getResource())));
		} catch (PubmedSearchException e) {
			Article article = new Article();
			article.setTitle("N/A");
			result.setArticle(article);
			logger.error(e, e);
		}
		return result;
	}

	/**
	 * Creates publication summary for a given model.
	 * 
	 * @param miriamData
	 *          {@link MiriamData} representing article
	 * @param model
	 *          model for which summary will be prepared
	 * @return publication summary for a given model and publication
	 */
	public PubmedAnnotatedElementsView create(MiriamData miriamData, Model model) {
		PubmedAnnotatedElementsView result = create(miriamData);
		Set<BioEntity> elements = model.getElementsByAnnotation(miriamData);
		for (Model submodel : model.getSubmodels()) {
			elements.addAll(submodel.getElementsByAnnotation(miriamData));
		}
		for (BioEntity annotatedObject : elements) {
			result.addElement(annotatedObject);
		}
		return result;
	}

	@Override
	public String createGson(PubmedAnnotatedElementsView object) {
		return new Gson().toJson(object);
	}

	@Override
	public MiriamData viewToObject(PubmedAnnotatedElementsView view) {
		throw new NotImplementedException();
	}
}
