package lcsb.mapviewer.services.view;

import java.io.Serializable;

import lcsb.mapviewer.model.map.layout.ReferenceGenome;
import lcsb.mapviewer.model.map.layout.ReferenceGenomeGeneMapping;

/**
 * View representation of the {@link ReferenceGenome}.
 * 
 * @author Piotr Gawron
 * 
 */
public class ReferenceGenomeGeneMappingView extends AbstractView<ReferenceGenomeGeneMapping> implements Serializable {

	/**
	 * 
	 */
	private static final long	serialVersionUID = 1L;

	/**
	 * {@link ReferenceGenomeGeneMapping#name}.
	 */
	private String						name;

	/**
	 * Url from which reference genome was downloaded.
	 */
	private String						sourceUrl;

	/**
	 * Local url where reference genome file can be accessed.
	 */
	private String						localUrl;

	/**
	 * Progess of downloading process (100 means file is downloaded).
	 */
	private double						downloadProgress;

	/**
	 * Default constructor.
	 * 
	 * @param object
	 *          {@link ReferenceGenome} which this view should visualize
	 */
	protected ReferenceGenomeGeneMappingView(ReferenceGenomeGeneMapping object) {
		super(object);
	}

	/**
	 * Default constructor. Should be used only for deserialization.
	 */
	protected ReferenceGenomeGeneMappingView() {
	}

	/**
	 * @return the name
	 * @see #name
	 */
	public String getName() {
		return name;
	}

	/**
	 * @param name
	 *          the name to set
	 * @see #name
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * @return the sourceUrl
	 * @see #sourceUrl
	 */
	public String getSourceUrl() {
		return sourceUrl;
	}

	/**
	 * @param sourceUrl
	 *          the sourceUrl to set
	 * @see #sourceUrl
	 */
	public void setSourceUrl(String sourceUrl) {
		this.sourceUrl = sourceUrl;
	}

	/**
	 * @return the localUrl
	 * @see #localUrl
	 */
	public String getLocalUrl() {
		return localUrl;
	}

	/**
	 * @param localUrl
	 *          the localUrl to set
	 * @see #localUrl
	 */
	public void setLocalUrl(String localUrl) {
		this.localUrl = localUrl;
	}

	/**
	 * @return the downloadProgress
	 * @see #downloadProgress
	 */
	public double getDownloadProgress() {
		return downloadProgress;
	}

	/**
	 * @param downloadProgress
	 *          the downloadProgress to set
	 * @see #downloadProgress
	 */
	public void setDownloadProgress(double downloadProgress) {
		this.downloadProgress = downloadProgress;
	}

}
