package lcsb.mapviewer.services.search.data;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;

import org.apache.commons.lang3.SerializationUtils;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;

import lcsb.mapviewer.model.map.model.Model;
import lcsb.mapviewer.services.ServiceTestFunctions;

public class FullReactionViewTest extends ServiceTestFunctions {

	@Autowired
	FullReactionViewFactory fullReactionViewFactory;

	@Before
	public void setUp() throws Exception {
	}

	@After
	public void tearDown() throws Exception {
	}

	@Test
	public void testSearialization() {
		try {
			SerializationUtils.serialize(new FullReactionView());
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}
	}

	@Test
	public void testConvertOk() throws Exception {
		try {
			String input = "(urn:miriam:ccds:CCDS8639.1) or (urn:miriam:ccds:CCDS26.1) or (urn:miriam:ccds:CCDS314.2) or (urn:miriam:ccds:CCDS314.1)";
			String output = fullReactionViewFactory.convertToHtml(input);
			assertNotNull(output);
			int count = 0;
			int index = 0;
			while (output.indexOf("href", index) > 0) {
				count++;
				index = output.indexOf("href", index) + 1;
			}
			assertEquals("4 urls expected in the output: " + output, 4, count);
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}
	}

	@Test
	public void testConvertInvalid() throws Exception {
		try {
			String input = "(urn:blabla:bla:CCDS8639.1)";
			String output = fullReactionViewFactory.convertToHtml(input);
			assertNotNull(output);
			assertEquals(input, output);
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}
	}

	@Test
	public void testConvertNull() throws Exception {
		try {
			String input = null;
			String output = fullReactionViewFactory.convertToHtml(input);
			assertNull(output);
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}
	}

	@Test
	public void testCreateView() throws Exception {
		try {
			Model model = getModelForFile("testFiles/sample.xml", true);
			FullReactionView view = fullReactionViewFactory.create(model.getReactionByReactionId("re1"));
			assertNotNull(view);
			assertTrue(view.getLines().size() > 0);
			assertTrue(view.getElements().size() > 0);
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}
	}

}
